# Table of Contents

- [setting-up-github-enterprise-integration](<./setting-up-github-enterprise-integration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Setting Up the GitHub Enterprise Integration](<./Setting-Up-the-GitHub-Enterprise-Integration.md>)
  - [Prerequisites](<./Setting-Up-the-GitHub-Enterprise-Integration/Prerequisites.md>)
  - [Step 1: Create a GitHub App](<./Setting-Up-the-GitHub-Enterprise-Integration/Step-1-Create-a-GitHub-App.md>)
  - [Step 2: Deploy the SAP LeanIX Agent](<./Setting-Up-the-GitHub-Enterprise-Integration/Step-2-Deploy-the-SAP-LeanIX-Agent.md>)
  - [Step 3: Install the GitHub App](<./Setting-Up-the-GitHub-Enterprise-Integration/Step-3-Install-the-GitHub-App.md>)
  - [Step 4: Add Manifest Files to Projects](<./Setting-Up-the-GitHub-Enterprise-Integration/Step-4-Add-Manifest-Files-to-Projects.md>)
  - [Step 5: Monitor and Manage the Integration](<./Setting-Up-the-GitHub-Enterprise-Integration/Step-5-Monitor-and-Manage-the-Integration.md>)
  - [Update the Agent Version](<./Setting-Up-the-GitHub-Enterprise-Integration/Update-the-Agent-Version.md>)
